[−][src]Crate dsf_rpc
Re-exports
pub use config::*; |
pub use data::*; |
pub use debug::*; |
pub use peer::*; |
pub use service::*; |
pub use replica::*; |
Modules
| config | |
| data | |
| debug | |
| display | |
| peer | |
| replica | |
| service |
Structs
| PageBounds | Paginator object supports paginating responses from the daemon |
| Request | RPC Request container for requests from a client to the daemon |
| Response | Response container for replies from the daemon to the client |
| ServiceIdentifier | |
| StatusInfo | |
| TimeBounds | TimeBounded object supports limiting queries by time |
Enums
| RequestKind | Specific request kinds for issuing requests to the daemon from the client |
| ResponseKind | Specific response kinds for processing responses from the daemon |
Traits
| Rpc | API trait implements RPC API for the daemon (or delegation) |
Type Definitions
| Body | Body may be empty, encrypted, or Cleartext |